from writer import Writer


class TXT(Writer):
    suffix = 'txt'
